quantizationtools.SearchTree
============================

.. abjad-lineage:: abjad.tools.quantizationtools.SearchTree.SearchTree

.. autoclass:: abjad.tools.quantizationtools.SearchTree.SearchTree

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.SearchTree.SearchTree.default_definition
      ~abjad.tools.quantizationtools.SearchTree.SearchTree.definition
      ~abjad.tools.quantizationtools.SearchTree.SearchTree.__call__
      ~abjad.tools.quantizationtools.SearchTree.SearchTree.__eq__
      ~abjad.tools.quantizationtools.SearchTree.SearchTree.__format__
      ~abjad.tools.quantizationtools.SearchTree.SearchTree.__hash__
      ~abjad.tools.quantizationtools.SearchTree.SearchTree.__ne__
      ~abjad.tools.quantizationtools.SearchTree.SearchTree.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.SearchTree.SearchTree.default_definition
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.SearchTree.SearchTree.definition
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.__hash__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.__repr__
   :noindex:
